#[unsafe(no_mangle)]pub unsafe extern "C" fn hide_buffer_free(buffer: *mut HideBuffer)Expand description
Frees a buffer produced by this library.
Safety
buffer must come from this library and must not be freed twice.
#[unsafe(no_mangle)]pub unsafe extern "C" fn hide_buffer_free(buffer: *mut HideBuffer)Frees a buffer produced by this library.
buffer must come from this library and must not be freed twice.